@@ -1,4 +1,6 @@
 pub mod ansi;
+pub mod batch_utf8;
+pub mod batched_parser;
 pub mod clipboard;
 pub mod config;
 pub mod crosswords;
@@ -6,5 +8,6 @@ pub mod error;
 pub mod event;
 pub mod performer;
 pub mod selection;
+pub mod simd_utf8;
 
 pub use sugarloaf;
